@@ -25,19 +25,22 @@ ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <string.h>
-#include <stdio.h>
+#include <R_ext/Boolean.h>
 #include "row_dominance.h"
-void row_dominance(int p_pichart[], int p_implicants[], int *p_ck, int pirows, int *foundPI, int nconds) {
-    int picols = *foundPI;
-    bool survcols[picols];
+void row_dominance(
+    int p_pichart[],
+    int p_implicants[],
+    int *p_ck,
+    int pirows,
+    unsigned int *foundPI,
+    int nconds
+) {
+    unsigned int picols = *foundPI;
+    Rboolean survcols[picols];
     int colsums[picols];
     int sortcol[picols];
     int temp;
-    for (int c = 0; c < picols; c++) {
+    for (unsigned int c = 0; c < picols; c++) {
         colsums[c] = 0;
         for (int r = 0; r < pirows; r++) {
             colsums[c] += p_pichart[c * pirows + r];
@@ -45,8 +48,8 @@ void row_dominance(int p_pichart[], int p_implicants[], int *p_ck, int pirows, i
         sortcol[c] = c;
         survcols[c] = true;
     }
-    for (int c1 = 0; c1 < picols; c1++) {
-        for (int c2 = c1 + 1; c2 < picols; c2++) {
+    for (unsigned int c1 = 0; c1 < picols; c1++) {
+        for (unsigned int c2 = c1 + 1; c2 < picols; c2++) {
             if (colsums[sortcol[c1]] < colsums[sortcol[c2]]) {
                 temp = sortcol[c1];
                 sortcol[c1] = sortcol[c2];
@@ -54,12 +57,12 @@ void row_dominance(int p_pichart[], int p_implicants[], int *p_ck, int pirows, i
             }
         }
     }
-    for (int c1 = 0; c1 < picols; c1++) {
+    for (unsigned int c1 = 0; c1 < picols; c1++) {
         if (survcols[sortcol[c1]]) {
-            for (int c2 = c1 + 1; c2 < picols; c2++) {
+            for (unsigned int c2 = c1 + 1; c2 < picols; c2++) {
                 if (survcols[sortcol[c2]]) {
                     if (colsums[sortcol[c1]] > colsums[sortcol[c2]]) {
-                        bool itcovers = true; 
+                        Rboolean itcovers = true; 
                         int r = 0;
                         while (r < pirows && itcovers) {
                             if (p_pichart[sortcol[c2] * pirows + r]) {
@@ -78,7 +81,7 @@ void row_dominance(int p_pichart[], int p_implicants[], int *p_ck, int pirows, i
     }
     if (*foundPI < picols) {
         int s = 0;
-        for (int c = 0; c < picols; c++) {
+        for (unsigned int c = 0; c < picols; c++) {
             if (survcols[c]) {
                 for (int r = 0; r < pirows; r++) {
                     p_pichart[s * pirows + r] = p_pichart[c * pirows + r];
