@@ -25,25 +25,32 @@ ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
+#include <R_ext/RS.h>
+#include <R_ext/Boolean.h>
 #include <float.h> 
-#include <stdio.h>
-#include <stdlib.h>
 #include <math.h>
-#include <string.h>
-#include <stdio.h>
 #include "utils.h"
-void resize(int **array, const int rows, const int newcols, const int oldcols) {
-    int* tmp = calloc(rows * newcols, sizeof(int));
-    int cols = (newcols > oldcols) ? oldcols : newcols;
-    for (int i = 0; i < rows * cols; i++) {
+void resize(
+    int **array,
+    const int rows,
+    const unsigned int newcols,
+    const unsigned int oldcols
+) {
+    int* tmp = R_Calloc(rows * newcols, int);
+    unsigned int cols = (newcols > oldcols) ? oldcols : newcols;
+    for (unsigned int i = 0; i < rows * cols; i++) {
         *(tmp + i) = *(*array + i);
     }
-    free(*array);
+    R_Free(*array);
     *array = tmp;   
 }
-bool too_complex(const int foundPI, const int solmin, const double maxcomb) {
+Rboolean too_complex(
+    const unsigned int foundPI,
+    const int solmin,
+    const double maxcomb
+) {
     double result = 1;
-    int n = foundPI;
+    unsigned int n = foundPI;
     int k = solmin;
     for (int i = 1; i <= k; i++) {
         result *= n - (k - i);
@@ -54,11 +61,16 @@ bool too_complex(const int foundPI, const int solmin, const double maxcomb) {
     }
     return(false);
 }
-void over_transpose(int matrix[], const int nr, const int nc, const int type) {
+void over_transpose(
+    int matrix[],
+    const int nr,
+    const int nc,
+    const int type
+) {
     int len = nr * nc;
     int i, j, l_1 = len - 1;
     if (type == 0) {
-        bool tmp[nr * nc];
+        Rboolean tmp[nr * nc];
         for (i = 0, j = 0; i < len; i++, j += nr) {
             if (j > l_1) j -= l_1;
             tmp[i] = matrix[j];
@@ -88,16 +100,25 @@ void over_transpose(int matrix[], const int nr, const int nc, const int type) {
         }
     }
 }
-bool altb(double a, double b) {
+Rboolean altb(double a, double b) {
     return (b - a) > ( (fabs(a) < fabs(b) ? fabs(b) : fabs(a)) * DBL_EPSILON);
 }
-bool agteb(double a, double b) {
+Rboolean agteb(double a, double b) {
     return((a > b) || (fabs(a - b) <= DBL_EPSILON));
 }
-bool nonredundant(const int p_implicants[], const int p_indx[], const int p_ck[], const int tempk[], const int tempc[], const int nconds, const int k, const int prevfoundPI) {
-    bool nonred = true;
+Rboolean nonredundant(
+    const int p_implicants[],
+    const int p_indx[],
+    const int p_ck[],
+    const int tempk[],
+    const int tempc[],
+    const int nconds,
+    const int k,
+    const unsigned int prevfoundPI
+) {
+    Rboolean nonred = true;
     if (prevfoundPI > 0) {
-        int i = 0;
+        unsigned int i = 0;
         while (i < prevfoundPI && nonred) {
             int sumeq = 0;
             int v = 0;
@@ -117,7 +138,21 @@ bool nonredundant(const int p_implicants[], const int p_indx[], const int p_ck[]
     }
     return(nonred);
 }
-void push_PI(int p_implicants[], int p_indx[], int p_ck[], int p_pichart[], const int tempk[], const int tempc[], const int nconds, const int k, const int f, const int decpos[], const int frows[], const int posrows, const int foundPI) {
+void push_PI(
+    int p_implicants[],
+    int p_indx[],
+    int p_ck[],
+    int p_pichart[],
+    const int tempk[],
+    const int tempc[],
+    const int nconds,
+    const int k,
+    const int f,
+    const int decpos[],
+    const int frows[],
+    const int posrows,
+    const unsigned int foundPI
+) {
     for (int c = 0; c < k; c++) {
         p_implicants[nconds * foundPI + tempk[c]] = tempc[c];
     }
@@ -129,7 +164,14 @@ void push_PI(int p_implicants[], int p_indx[], int p_ck[], int p_pichart[], cons
         p_pichart[posrows * foundPI + r] = decpos[r] == decpos[frows[f]];
     }
 }
-void increment(int k, int *e, int *h, int nconds, int *tempk, int minval) {
+void increment(
+    int k,
+    int *e,
+    int *h,
+    int nconds,
+    int *tempk,
+    int minval
+) {
     if (k == 1) {
         tempk[0] += 1;
     }
@@ -146,7 +188,7 @@ void increment(int k, int *e, int *h, int nconds, int *tempk, int minval) {
         else {
             *e = tempk[k - *h - 1] + 1;
             ++*h;
-            bool under = true;
+            Rboolean under = true;
             for (int j = 0; j < *h; j++) {
                 under = under && (*e + j < minval);
                 tempk[k - *h + j] = *e + j;
@@ -159,7 +201,16 @@ void increment(int k, int *e, int *h, int nconds, int *tempk, int minval) {
         }
     }
 }
-void populate_posneg(int *rowpos, int *rowneg, int nconds, int ttrows, int posrows, const int p_tt[], int posmat[], int negmat[]) {
+void populate_posneg(
+    int *rowpos,
+    int *rowneg,
+    int nconds,
+    int ttrows,
+    int posrows,
+    const int p_tt[],
+    int posmat[],
+    int negmat[]
+) {
     int negrows = ttrows - posrows;
     for (int r = 0; r < ttrows; r++) {
         if (p_tt[nconds * ttrows + r] == 1) { 
@@ -177,7 +228,12 @@ void populate_posneg(int *rowpos, int *rowneg, int nconds, int ttrows, int posro
     }
     return;
 }
-void get_noflevels(int noflevels[], const int p_tt[], int nconds, int ttrows) {
+void get_noflevels(
+    int noflevels[],
+    const int p_tt[],
+    int nconds,
+    int ttrows
+) {
     for (int c = 0; c < nconds; c++) {
         noflevels[c] = 0; 
     }
@@ -191,12 +247,27 @@ void get_noflevels(int noflevels[], const int p_tt[], int nconds, int ttrows) {
     }
     return;
 }
-void fill_mbase(int mbase[], const int tempk[], const int noflevels[], const int k) {
+void fill_mbase(
+    int mbase[],
+    const int tempk[],
+    const int noflevels[],
+    const int k
+) {
     for (int c = 1; c < k; c++) {
         mbase[c] = mbase[c - 1] * noflevels[tempk[c - 1]];
     }
 }
-void get_decimals(const int posrows, const int negrows, const int k, int decpos[], int decneg[], const int posmat[], const int negmat[], const int tempk[], const int mbase[]) {
+void get_decimals(
+    const int posrows,
+    const int negrows,
+    const int k,
+    int decpos[],
+    int decneg[],
+    const int posmat[],
+    const int negmat[],
+    const int tempk[],
+    const int mbase[]
+) {
     for (int r = 0; r < posrows; r++) {
         decpos[r] = 0;
         for (int c = 0; c < k; c++) {
@@ -210,10 +281,16 @@ void get_decimals(const int posrows, const int negrows, const int k, int decpos[
         }
     }
 }
-void get_uniques(const int posrows, int *found, int decpos[], bool possiblePI[], int possiblePIrows[]) {
+void get_uniques(
+    const int posrows,
+    int *found,
+    int decpos[],
+    Rboolean possiblePI[],
+    int possiblePIrows[]
+) {
     for (int r = 1; r < posrows; r++) {
         int prev = 0;
-        bool unique = true; 
+        Rboolean unique = true; 
         while (prev < *found && unique) {
             unique = decpos[possiblePIrows[prev]] != decpos[r];
             prev += 1;
@@ -225,7 +302,15 @@ void get_uniques(const int posrows, int *found, int decpos[], bool possiblePI[],
         }
     }
 }
-void verify_possible_PI(const int compare, const int negrows, int *found, bool possiblePI[], const int possiblePIrows[], const int decpos[], const int decneg[]) {
+void verify_possible_PI(
+    const int compare,
+    const int negrows,
+    int *found,
+    Rboolean possiblePI[],
+    const int possiblePIrows[],
+    const int decpos[],
+    const int decneg[]
+) {
     for (int i = 0; i < compare; i++) {
         int j = 0;
         while (j < negrows && possiblePI[i]) {
@@ -237,7 +322,12 @@ void verify_possible_PI(const int compare, const int negrows, int *found, bool p
         }
     }
 }
-void get_frows(int frows[], const bool possiblePI[], const int possiblePIrows[], const int compare) {
+void get_frows(
+    int frows[],
+    const Rboolean possiblePI[],
+    const int possiblePIrows[],
+    const int compare
+) {
     int pos = 0;
     for (int i = 0; i < compare; i++) {
         if (possiblePI[i]) {
@@ -246,7 +336,15 @@ void get_frows(int frows[], const bool possiblePI[], const int possiblePIrows[],
         }
     }
 }
-void fill_matrix(int nrows, int ncols, int nofl[], int *matrix, int startrow, int cols[], int plus1) {
+void fill_matrix(
+    int nrows,
+    int ncols,
+    int nofl[],
+    int *matrix,
+    int startrow,
+    int cols[],
+    int plus1
+) {
     int mbase[ncols];
     int orep[ncols];
     for (int c = 0; c < ncols; c++) {
@@ -270,7 +368,13 @@ void fill_matrix(int nrows, int ncols, int nofl[], int *matrix, int startrow, in
         }
     }
 }
-void calculate_rows(int *nrows, int ncols, int nofl[], int arrange, int maxprod) {
+void calculate_rows(
+    int *nrows,
+    int ncols,
+    int nofl[],
+    int arrange,
+    int maxprod
+) {
     *nrows = 0;
     int e, h, k, prod;
     if (arrange == 0) {
@@ -305,7 +409,13 @@ void calculate_rows(int *nrows, int ncols, int nofl[], int arrange, int maxprod)
         }
     }
 }
-int fillCombinationTasks(const int n, int k, int (*comb)[3], const int arrayMaxSize, int* outNumItemsFilled) {  
+int fillCombinationTasks(
+    const int n,
+    int k,
+    int (*comb)[3],
+    const int arrayMaxSize,
+    int* outNumItemsFilled
+) {  
     *outNumItemsFilled = 0;
     if (k <= 1)
     {
@@ -343,7 +453,12 @@ int fillCombinationTasks(const int n, int k, int (*comb)[3], const int arrayMaxS
         return 3;
     }
 }
-int GetNextComb(int *arr, int k, int n, int indexLimit) {
+int GetNextComb(
+    int *arr,
+    int k,
+    int n,
+    int indexLimit
+) {
     int i;
     for (i = k - 1; i >= indexLimit; --i)
     {
@@ -357,12 +472,16 @@ int GetNextComb(int *arr, int k, int n, int indexLimit) {
         arr[j] = arr[j-1] + 1;
     return 1;
 }
-bool all_covered(const int p_pichart[], const int pirows, const int picols) {
-    bool allrows = true;
+Rboolean all_covered(
+    const int p_pichart[],
+    const int pirows,
+    const unsigned int picols
+) {
+    Rboolean allrows = true;
     int r = 0;
     while (r < pirows && allrows) {
-        bool covered = false;
-        int c = 0;
+        Rboolean covered = false;
+        unsigned int c = 0;
         while (c < picols && !covered) {
             covered = p_pichart[c * pirows + r];
             c++;
